mynow

package
v0.0.0-...-fe5d015 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var TimeFormats = []string{
	"2006", "2006-1", "2006-1-2", "2006-1-2 15", "2006-1-2 15:4", "2006-1-2 15:4:5", "1-2",
	"15:4:5", "15:4", "15",
	"15:4:5 Jan 2, 2006 MST", "2006-01-02 15:04:05.999999999 -0700 MST", "2006-01-02T15:04:05-07:00",
	"2006.1.2", "2006.1.2 15:04:05", "2006.01.02", "2006.01.02 15:04:05", "2006.01.02 15:04:05.999999999",
	"1/2/2006", "1/2/2006 15:4:5", "2006/01/02", "2006/01/02 15:04:05",
	time.ANSIC, time.UnixDate, time.RubyDate, time.RFC822, time.RFC822Z, time.RFC850,
	time.RFC1123, time.RFC1123Z, time.RFC3339, time.RFC3339Nano,
	time.Kitchen, time.Stamp, time.StampMilli, time.StampMicro, time.StampNano,
}
var WeekStartDay = time.Sunday

Functions

func BeginningOfDay

func BeginningOfDay() time.Time

BeginningOfDay beginning of day

func BeginningOfHour

func BeginningOfHour() time.Time

BeginningOfHour beginning of hour

func BeginningOfMinute

func BeginningOfMinute() time.Time

BeginningOfMinute beginning of minute

func BeginningOfMonth

func BeginningOfMonth() time.Time

BeginningOfMonth beginning of month

func BeginningOfQuarter

func BeginningOfQuarter() time.Time

BeginningOfQuarter beginning of quarter

func BeginningOfWeek

func BeginningOfWeek() time.Time

BeginningOfWeek beginning of week

func BeginningOfYear

func BeginningOfYear() time.Time

BeginningOfYear beginning of year

func Between

func Between(time1, time2 string) bool

Between check now between the begin, end time or not

func EndOfDay

func EndOfDay() time.Time

EndOfDay end of day

func EndOfHour

func EndOfHour() time.Time

EndOfHour end of hour

func EndOfMinute

func EndOfMinute() time.Time

EndOfMinute end of minute

func EndOfMonth

func EndOfMonth() time.Time

EndOfMonth end of month

func EndOfQuarter

func EndOfQuarter() time.Time

EndOfQuarter end of quarter

func EndOfSunday

func EndOfSunday() time.Time

EndOfSunday end of sunday

func EndOfWeek

func EndOfWeek() time.Time

EndOfWeek end of week

func EndOfYear

func EndOfYear() time.Time

EndOfYear end of year

func Monday

func Monday() time.Time

Monday monday

func MustParse

func MustParse(strs ...string) time.Time

func MustParseInLocation

func MustParseInLocation(loc *time.Location, strs ...string) time.Time

func Parse

func Parse(strs ...string) (time.Time, error)

func ParseInLocation

func ParseInLocation(loc *time.Location, strs ...string) (time.Time, error)

func Sunday

func Sunday() time.Time

Sunday sunday

Types

type Config

type Config struct {
	WeekStartDay time.Weekday
	TimeLocation *time.Location
	TimeFormats  []string
}

Config configuration for now package

var DefaultConfig *Config

DefaultConfig default config

func (*Config) MustParse

func (config *Config) MustParse(strs ...string) time.Time

MustParse must parse string to time or will panic

func (*Config) Parse

func (config *Config) Parse(strs ...string) (time.Time, error)

Parse parse string to time based on configuration

func (*Config) With

func (config *Config) With(t time.Time) *Now

type Now

type Now struct {
	time.Time
	*Config
}

Now now struct

func New

func New(t time.Time) *Now

New initialize Now with time

func With

func With(t time.Time) *Now

With initialize Now with time

func (*Now) BeginningOfDay

func (now *Now) BeginningOfDay() time.Time

func (*Now) BeginningOfHalf

func (now *Now) BeginningOfHalf() time.Time

func (*Now) BeginningOfHour

func (now *Now) BeginningOfHour() time.Time

func (*Now) BeginningOfMinute

func (now *Now) BeginningOfMinute() time.Time

func (*Now) BeginningOfMonth

func (now *Now) BeginningOfMonth() time.Time

func (*Now) BeginningOfQuarter

func (now *Now) BeginningOfQuarter() time.Time

BeginningOfQuarter beginning of quarter

func (*Now) BeginningOfWeek

func (now *Now) BeginningOfWeek() time.Time

func (*Now) BeginningOfYear

func (now *Now) BeginningOfYear() time.Time

func (*Now) Between

func (now *Now) Between(begin, end string) bool

Between check time between the begin, end time or not

func (*Now) EndOfDay

func (now *Now) EndOfDay() time.Time

func (*Now) EndOfHalf

func (now *Now) EndOfHalf() time.Time

func (*Now) EndOfHour

func (now *Now) EndOfHour() time.Time

func (*Now) EndOfMinute

func (now *Now) EndOfMinute() time.Time

func (*Now) EndOfMonth

func (now *Now) EndOfMonth() time.Time

func (*Now) EndOfQuarter

func (now *Now) EndOfQuarter() time.Time

func (*Now) EndOfSunday

func (now *Now) EndOfSunday() time.Time

func (*Now) EndOfWeek

func (now *Now) EndOfWeek() time.Time

func (*Now) EndOfYear

func (now *Now) EndOfYear() time.Time

func (*Now) Monday

func (now *Now) Monday() time.Time

func (*Now) Parse

func (now *Now) Parse(strs ...string) (t time.Time, err error)

Parse parse string to time

func (*Now) Sunday

func (now *Now) Sunday() time.Time

Jump to